@@ -1,17 +1,27 @@
-`rwmGetColours` <-
-function(colourPalette, numColours)
+#' to choose map colours for classified data
+#' 
+#' Returns a vector of colours based upon the palette specified and number of
+#' colours specified.  If colourPalette specifies a number of colours and this
+#' is different from numColours, numColours takes precedence and colours are
+#' interpolated to make the number fit.
+#' 
+#' @param colourPalette string describing the colour palette to use, choice of:
+#' \enumerate{ \item "palette" for the current palette \item a vector of valid
+#' colours, e.g. =c('red','white','blue') or output from RColourBrewer \item one
+#' of "heat", "diverging", "white2Black", "black2White", "topo", "rainbow",
+#' "terrain", "negpos8", "negpos9" }
+#' @param numColours the number of colour categories desired
+#' @return A vector specifiying a number of colours.
+#' @export
+rwmGetColours <- function(colourPalette, numColours)
 {
-#browser()
 
 #if invalid option is chosen it's set to palette at end
 paletteList <- c("white2Black","black2White","palette","heat","topo","terrain","rainbow","negpos8","negpos9")
 
-#!next add some of these neg pos options work out how to make them flexible to numCats  
-#'negpos9zero': begin
-#  names=['dblue','blue','lblue','lgreen','lgrey','yellow','orange','red','purple']
 
 #to allow user specified colours
-#! this could test whether colours are valid
+#this could test whether colours are valid
 if( length(colourPalette) > 1 ) #only if the colourPalette passed is a vector of length > 1
 	{
 		#coloursToUse <- colourPalette
@@ -22,13 +32,13 @@ if( length(colourPalette) > 1 ) #only if the colourPalette passed is a vector of
     else 
         {
          warning(length(colourPalette)," colours specified and ", numColours," required, using interpolation to calculate colours")
-         coloursToUse<-colorRampPalette(colourPalette)(numColours)
+         coloursToUse<-colorRampPalette(colourPalette,alpha=TRUE)(numColours)
          #coloursToUse<-colorRampPalette(colourPalette,space = "Lab")(numColours) #tried this to preserve transparency, didn't work
         }					
 	} else
 if(colourPalette=="negpos9")
 	{
-	  #! later add that these can cope with diff num cats too
+	  #later add that these can cope with diff num cats too
 		coloursToUse <- c('darkblue','blue','lightblue','lightgreen','grey','yellow','orange','red','darkred')#'purple')
 	} else		
 if(colourPalette=="negpos8")
